package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.huiju.estateagents.service.ITdNewsTypeService;
import com.huiju.estateagents.entity.TdNewsType;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资讯分类  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-06-11
 */
@RestController
@RequestMapping("/")
public class TdNewsTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdNewsTypeController.class);

    @Autowired
    public ITdNewsTypeService iTdNewsTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tdNewsType",method= RequestMethod.GET)
    public ResponseBean tdNewsTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TdNewsType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdNewsType> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TdNewsType> result = iTdNewsTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdNewsTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param tdNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdNewsType",method= RequestMethod.POST)
    public ResponseBean tdNewsTypeAdd(@RequestBody TdNewsType tdNewsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdNewsTypeService.save(tdNewsType)){
                responseBean.addSuccess(tdNewsType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdNewsTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdNewsType/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdNewsTypeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdNewsTypeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdNewsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdNewsType 实体对象
     * @return
     */
    @RequestMapping(value="/tdNewsType/{id}",method= RequestMethod.PUT)
    public ResponseBean tdNewsTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TdNewsType tdNewsType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdNewsTypeService.updateById(tdNewsType)){
                responseBean.addSuccess(tdNewsType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdNewsTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdNewsType/{id}",method= RequestMethod.GET)
    public ResponseBean tdNewsTypeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdNewsTypeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("tdNewsTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
