package com.huiju.estateagents.miniPackage.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.miniPackage.entity.SysVipPackage;
import com.huiju.estateagents.miniPackage.service.ISysVipPackageService;

/**
 * <p>
    * 会员套餐  前端控制器
    * </p>
 *
 * @author wxx
 * @since 2020-06-16
 */
@RestController
@RequestMapping("/api")
public class SysVipPackageController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysVipPackageController.class);

    @Autowired
    public ISysVipPackageService iSysVipPackageService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysVipPackage",method= RequestMethod.GET)
    public ResponseBean sysVipPackageList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysVipPackage> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysVipPackage> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysVipPackage> result = iSysVipPackageService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysVipPackage 实体对象
     * @return
     */
    @RequestMapping(value="/sysVipPackage",method= RequestMethod.POST)
    public ResponseBean sysVipPackageAdd(@RequestBody SysVipPackage sysVipPackage){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysVipPackageService.save(sysVipPackage)){
                responseBean.addSuccess(sysVipPackage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysVipPackage/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysVipPackageDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysVipPackageService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysVipPackage 实体对象
     * @return
     */
    @RequestMapping(value="/sysVipPackage/{id}",method= RequestMethod.PUT)
    public ResponseBean sysVipPackageUpdate(@PathVariable Integer id,
                                        @RequestBody SysVipPackage sysVipPackage){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysVipPackageService.updateById(sysVipPackage)){
                responseBean.addSuccess(sysVipPackage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysVipPackage/{id}",method= RequestMethod.GET)
    public ResponseBean sysVipPackageGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysVipPackageService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysVipPackageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
